@@ -996,11 +996,6 @@ def highly_parallel_job_manager(options, exec_filename,
     memory_per_cpu = options['memory_per_cpu']
     only_gather = options['only_gather']
 
-    print("ONLY GATHER", only_gather)
-    if not only_gather:
-        print("STOP")
-        exit(1)
-
     log_txt = ("#RUN LOG\n\n"
         "Run type (local / shared / remote) :\t{0}\n").format(protocol)
     if protocol != 'local':
